# This file should ensure the existence of records required to run the application in every environment (production,
# development, test). The code here should be idempotent so that it can be executed at any point in every environment.
# The data can then be loaded with the bin/rails db:seed command (or created alongside the database with db:setup).
#
# Example:
#
#   ["Action", "Comedy", "Drama", "Horror"].each do |genre_name|
#     MovieGenre.find_or_create_by!(name: genre_name)
#   end

# Conference.find_or_create_by(slug: "rp2023").tap do |c|
#   c.name = "re:publica 2023"
#   c.time_zone = "Berlin"
#   c.starts_at = DateTime.parse("Mon, 05 Jun 2023 08:30:00.000000000 UTC +00:00")
#   c.ends_at = DateTime.parse("Wed, 07 Jun 2023 20:50:00.000000000 UTC +00:00")
#   c.data = {
#     "speakers_url" => "https://re-publica.com/sites/default/files/extappdata/2023/speaker.json",
#     "sessions_url" => "https://re-publica.com/sites/default/files/extappdata/2023/session.json"
#   }
#   c.import_job_class = "republica_2023_or_later"
#   c.location = "Arena Berlin"
#   c.save!
# end

# Conference.find_or_create_by(slug: "rp2024").tap do |c|
#   c.name = "re:publica 2024"
#   c.time_zone = "Berlin"
#   c.starts_at = DateTime.parse("27 May 2024 10:30 CEST")
#   c.ends_at = DateTime.parse("29 May 2024 19:45 CEST")
#   c.data = {
#     "speakers_url" => "https://re-publica.com/sites/default/files/extappdata/2024/speaker.json",
#     "sessions_url" => "https://re-publica.com/sites/default/files/extappdata/2024/session.json"
#   }
#   c.import_job_class = "republica_2023_or_later"
#   c.location = "STATION Berlin"
#   c.save!
# end

# Conference.find_or_create_by(slug: "37c3").tap do |c|
#   c.name = "37th Chaos Communication Congress"
#   c.time_zone = "Berlin"
#   c.starts_at = DateTime.parse("27 December 2023 10:30 CET")
#   c.ends_at = DateTime.parse("30 December 2023 19:00 CET")
#   c.data = {
#     "schedule_url" => "https://fahrplan.events.ccc.de/congress/2023/fahrplan/schedule.json"
#   }
#   c.import_job_class = "pretalx"
#   c.location = "Congress Center Hamburg"
#   c.save!
# end

Conference.find_or_create_by(slug: "38c3").tap do |c|
  c.name = "38th Chaos Communication Congress (de-en)"
  c.time_zone = "Berlin"
  c.starts_at = DateTime.parse("27 December 2024 10:30 CET")
  c.ends_at = DateTime.parse("30 December 2024 19:00 CET")
  c.data = {
    "schedule_url" => "https://api.events.ccc.de/congress/2024/assembly/6840c453-af5c-413c-8127-adcbdcd98e9e/schedule.json",
    "filedrop" => {
      "url" => "https://speakers.c3lingo.org"
    }

  }
  c.import_job_class = "pretalx"
  c.location = "Congress Center Hamburg"
  c.save!
end

Conference.find_or_create_by(slug: "38c3-more").tap do |c|
  c.name = "38th Chaos Communication Congress (more languages)"
  c.time_zone = "Berlin"
  c.starts_at = DateTime.parse("27 December 2024 10:30 CET")
  c.ends_at = DateTime.parse("30 December 2024 19:00 CET")
  c.data = {
    "schedule_url" => "https://api.events.ccc.de/congress/2024/assembly/6840c453-af5c-413c-8127-adcbdcd98e9e/schedule.json",
    "filedrop" => {
      "url" => "https://speakers.c3lingo.org",
      "skip_downloads" => true
    }
  }
  c.import_job_class = "pretalx"
  c.location = "Congress Center Hamburg"
  c.save!
end

if Rails.env.development?
  %w[coverage fog comedy adjust forge fail vigorous promise chemistry conception meat storage certain warm develop civilian cousin injection hammer health appetite conventional good snake grant suspect atmosphere linen wrong deal calf sea management silence watch nuance loan quit convert failure bracket slice sweat treaty plot still chimpanzee assume functional marsh dream mail state dorm kid formation secular agile beach guide salesperson merit goalkeeper incongruous cart pig joystick regulation apparatus myth patent glue behead flu departure spectrum parking indication delay hesitate viable lay treat cooperative sensation auction sphere stain tap pass].each do |username|
    User.find_or_create_by(name: username) do |u|
      u.email = "c3lingo+#{username}@x.moeffju.net"
      u.invitation_token = "gargamel"
      u.save!
    end
  end
end

if token = fetch_credential("telegram_bot_token")
  NotificationChannel.find_or_create_by(name: "telegram_group_chat").tap do |c|
    c.data = { token: token }
    c.save!
  end
end
